import os

from evote.settings import *  # noqa


DEBUG = True
TEMPLATE_DEBUG = True
THUMBNAIL_DEBUG = True


# debug toolbar settings

def show_toolbar(request):
    return True


DEBUG_TOOLBAR_PATCH_SETTINGS = False
INSTALLED_APPS += (  # noqa
    'debug_toolbar',
)
MIDDLEWARE_CLASSES += [  # noqa
    'debug_toolbar.middleware.DebugToolbarMiddleware',
]
DEBUG_TOOLBAR_CONFIG = {
    "SHOW_TOOLBAR_CALLBACK": show_toolbar,
}


# database settings

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': os.environ.get('MYSQL_DATABASE'),
        'USER': os.environ.get('MYSQL_USER'),
        'PASSWORD': os.environ.get('MYSQL_PASSWORD'),
        'HOST': 'db',
        'PORT': '3306'
    }
}


# caching settings

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": os.environ.get('REDIS_PORT'),
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}


# celery settings

BROKER_URL = 'amqp://{}:{}@rabbitmq//'.format(
    os.environ.get('RABBITMQ_DEFAULT_USER'),
    os.environ.get('RABBITMQ_DEFAULT_PASS'))


# sorl thumbnail settings

THUMBNAIL_REDIS_URL = os.environ.get('REDIS_PORT')
THUMBNAIL_KVSTORE = "sorl.thumbnail.kvstores.redis_kvstore.KVStore"
THUMBNAIL_DUMMY = True
THUMBNAIL_DEBUG = True

# Celery email backend
CELERY_EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'

# Email settings
DEFAULT_FROM_EMAIL = 'dev@eurotux.com'
EVOTE_MAILING_SUBJECT_DEFAULT = 'Evote'

# evote services endpoints

EVOTE_ANONYMIZER_ENDPOINT = 'http://anonymizerservice/api/v1/'
EVOTE_ANONYMIZER_INIT_ELECTION = EVOTE_ANONYMIZER_ENDPOINT + 'initialize/'
EVOTE_ANONYMIZER_CLOSE_ELECTION = EVOTE_ANONYMIZER_ENDPOINT + 'close/'
EVOTE_ANONYMIZER_INSERT_VOTE = EVOTE_ANONYMIZER_ENDPOINT + 'anonymizevote/'

# Django Site identification
SITE_ID = 1
