from django.test import SimpleTestCase

# import evote.formats.en.formats as formats_en
import evote.formats.pt.formats as formats_pt


class CeleryTest(SimpleTestCase):

    def test_load_app(self):
        from evote.celery import app
        from celery import Celery
        self.assertIsInstance(app, Celery)


class WsgiTest(SimpleTestCase):

    def test_load_wsgi(self):
        from evote.wsgi import application
        self.assertIsNotNone(application._request_middleware)


class FormatsTest(SimpleTestCase):

    # def test_formats_en(self):

    #   self.assertEqual(formats_en.DATETIME_FORMAT, 'd-m-Y H:i')
    #   self.assertEqual(formats_en.DATETIME_INPUT_FORMATS, ['%d-%m-%Y %H:%M'])

    def test_formats_pt(self):
        self.assertEqual(formats_pt.DATETIME_FORMAT, 'd-m-Y H:i')
        self.assertEqual(formats_pt.DATETIME_INPUT_FORMATS, ['%d-%m-%Y %H:%M'])


class SettingsTest(SimpleTestCase):
    """ """

    def test_base_settings(self):
        """ """
        import evote.settings as base
        self.assertTrue(hasattr(base, "SECRET_KEY"))

    def test_base_admin_settings(self):
        """ """
        import evote.settings.admin as admin
        self.assertEqual(admin.ROOT_URLCONF, 'evote.urls.admin')

    def test_base_management_settings(self):
        """ """
        import evote.settings.management as management
        self.assertEqual(management.ROOT_URLCONF, 'evote.urls.management')

    def test_docker_settings(self):
        """ """
        import evote.settings.docker as docker
        self.assertTrue(docker.DEBUG)
        self.assertTrue(docker.show_toolbar(object()))

    def test_docker_admin_settings(self):
        """ """
        import evote.settings.docker.admin as admin
        self.assertEqual(admin.ROOT_URLCONF, 'evote.urls.admin')

    def test_docker_management_settings(self):
        """ """
        import evote.settings.docker.management as management
        self.assertEqual(management.ROOT_URLCONF, 'evote.urls.management')

    def test_production_settings(self):
        """ """
        import evote.settings.production as production
        self.assertFalse(production.DEBUG)
        self.assertEqual(production.ALLOWED_HOSTS, ['evote.com'])

    def test_production_admin_settings(self):
        """ """
        import evote.settings.production.admin as admin
        self.assertFalse(admin.DEBUG)
        self.assertEqual(admin.ALLOWED_HOSTS, ['admin.evote.com'])

    def test_production_management_settings(self):
        """ """
        import evote.settings.production.management as management
        self.assertFalse(management.DEBUG)
        self.assertEqual(management.ALLOWED_HOSTS, ['manage.evote.com'])

    def test_staging_settings(self):
        """ """
        import evote.settings.staging as staging
        self.assertFalse(staging.DEBUG)
        self.assertEqual(staging.ALLOWED_HOSTS, ['evote.dev.eurotux.com'])

    def test_staging_admin_settings(self):
        """ """
        import evote.settings.staging.admin as admin
        self.assertFalse(admin.DEBUG)
        self.assertEqual(admin.ALLOWED_HOSTS, ['evote-admin.dev.eurotux.com'])

    def test_staging_management_settings(self):
        """ """
        import evote.settings.staging.management as management
        self.assertFalse(management.DEBUG)
        self.assertEqual(
            management.ALLOWED_HOSTS, ['evote-manage.dev.eurotux.com'])
