from __future__ import unicode_literals

from django.test import TestCase
from django import forms

from evoteusers.tests.utils import UserTestUtils
from evoteusers.forms import EvoteAuthenticationForm


class EvoteAuthenticationFormTest(TestCase, UserTestUtils):
    """ """

    def setUp(self):
        self.credentials = {'email': 'dev@eurotux.com', 'password': 'password'}
        self.user = self.create_user(**self.credentials)

    def test_default(self):
        form = EvoteAuthenticationForm(data=self.credentials)
        self.assertTrue(form.is_valid())
        self.assertEqual(form.get_user(), self.user)

    def test_empty(self):
        form = EvoteAuthenticationForm(data={})
        self.assertFalse(form.is_valid())
        self.assertEqual(form.errors, {
            "email": ["This field is required."],
            "password": ["This field is required."]
        })

    def test_with_invalid_credentials(self):
        self.credentials['password'] = 'wrong'
        form = EvoteAuthenticationForm(data=self.credentials)
        self.assertFalse(form.is_valid())
        self.assertIsNone(form.get_user())

    def test_with_inactive_user(self):
        self.user.is_active = False
        self.user.save()
        form = EvoteAuthenticationForm(data=self.credentials)
        self.assertFalse(form.is_valid())
        with self.assertRaisesMessage(
                forms.ValidationError, 'This account is inactive.'):
            form.confirm_login_allowed(self.user)

    def test_get_user_id_with_valid_authentication(self):
        form = EvoteAuthenticationForm(data=self.credentials)
        self.assertTrue(form.is_valid())
        self.assertEqual(form.get_user_id(), self.user.id)

    def test_get_user_id_with_invalid_authentication(self):
        self.credentials['password'] = 'wrong'
        form = EvoteAuthenticationForm(data=self.credentials)
        self.assertFalse(form.is_valid())
        self.assertEqual(form.get_user_id(), None)
