from django.apps import apps

from evotevotings.elections.importers import ElectoralRollImporter
from celery.utils.log import get_task_logger
from evote.celery import app
from django_fsm import can_proceed
from .mailings import (PropositionBeginNotificationMail,
                       PropositionEndNotificationMail,
                       VotingBeginNotificationMail,
                       MinuteEndNotificationMail,
                       RollBeginNotificationMail,
                       RollEndNotificationMail)


logger = get_task_logger(__name__)


def get_election(pk):
    Election = apps.get_model("evoteelections.Election")  # noqa
    return Election.objects.get(pk=pk)


def get_electoral_roll(pk):
    ElectoralRoll = apps.get_model("evoteelections.ElectoralRoll")  # noqa
    return ElectoralRoll.objects.get(pk=pk)


@app.task(ignore_result=True)
def begin_election_proposition(election_id):
    election = get_election(election_id)
    if can_proceed(election.begin_proposition):
        election.begin_proposition()
        election.save()


@app.task(ignore_result=True)
def end_election_proposition(election_id):
    election = get_election(election_id)
    if can_proceed(election.end_proposition):
        election.end_proposition()
        election.save()


@app.task(ignore_result=True)
def open_election_voting(election_id):
    election = get_election(election_id)
    if can_proceed(election.voting):
        election.voting()
        election.save()


@app.task(ignore_result=True)
def close_elections(election_id):
    election = get_election(election_id)
    if can_proceed(election.close):
        election.close()
        election.save()


@app.task(ignore_result=True)
def import_electoral_roll(electoral_roll_id):
    electoral_roll = get_electoral_roll(electoral_roll_id)
    try:
        importer = ElectoralRollImporter(electoral_roll.election)
        importer.run(electoral_roll.document.document)
    except Exception:
        logger.exception("Error importing electoral roll")
    finally:
        electoral_roll.imported = True
        electoral_roll.save()


# Email notifications
@app.task(ignore_result=True)
def proposition_start_notification(election_id, days):
    election = get_election(election_id)
    PropositionBeginNotificationMail({'object': election, 'days': days})\
        .send(election.electoral_process)


@app.task(ignore_result=True)
def proposition_end_notification(election_id, days):
    election = get_election(election_id)
    PropositionEndNotificationMail({'object': election, 'days': days})\
        .send(election.electoral_process)


@app.task(ignore_result=True)
def voting_begin_notification(election_id, days):
    election = get_election(election_id)
    VotingBeginNotificationMail({'object': election, 'days': days})\
        .send(election.electoral_process)


@app.task(ignore_result=True)
def minute_end_notification(election_id, days):
    election = get_election(election_id)
    MinuteEndNotificationMail({'object': election, 'days': days})\
        .send(election.electoral_process)


@app.task(ignore_result=True)
def roll_begin_notification(election_id, days):
    election = get_election(election_id)
    RollBeginNotificationMail({'object': election, 'days': days})\
        .send(election.electoral_process)


@app.task(ignore_result=True)
def roll_end_notification(election_id, days):
    election = get_election(election_id)
    RollEndNotificationMail({'object': election, 'days': days})\
        .send(election.electoral_process)
