/* globals jQuery, django */

/******************************************************************
 * Site Name: eVote
 * Author: Sandro Rodrigues
 *
 * JavaScript: Management script
 *****************************************************************/

"use strict";

(function($) {

    $.fn.shuffle = function (options)
    {
        var opts = $.extend({
            onShuffleFinish: null,
        }, options);

        return this.each(function ()
        {
            var itemsName = $(this).data('shuffle'),
                $parent = $("[data-shuffle-container='" + itemsName + "']");

            $(this).on('click', function (e) {
                e.preventDefault();

                var $items = $parent.find("> *");
                var $shuffled = _.shuffle($items.clone(true));

                $items.hide("fade", {}, 200).delay(200, function () {
                    $parent.empty().html($shuffled);

                    if ($.isFunction( opts.onShuffleFinish )) {
                        opts.onShuffleFinish($shuffled);
                    }
                });
            });
        });
    };

    $.fn.actionValidationForms = function(options) {

        var opts = $.extend({
            flagWasValidatedAttr: "wasValidated",

        }, options);

        return this.each(function()
        {
            var $form = $(this);

            $form.on("submit", function() {

                var wasValidated = !! $form.data(opts.flagWasValidatedAttr);

                if ( !wasValidated )
                {
                    var modalOptions = {
                        remodal: {
                            hashTracking: false,
                            closeOnEscape: false,
                            closeOnOutsideClick: false
                        }
                    };
                    $.modalPartial( $form.data("action-validate"), modalOptions )
                        .done(function(modal)
                        {
                            modal.find('form').djangoAjaxForms({
                                onSubmitSuccess: function()
                                {
                                    modal.remodal().close();
                                    $form.data(opts.flagWasValidatedAttr, true)
                                    $form.trigger("submit");
                                }
                            });
                        });
                }

                return wasValidated;
            });
        });
    };


    $(document).ready(function () {

        $("[data-action-validate]").actionValidationForms();

        $("[data-shuffle]").shuffle();

        // Copy dates of first form to the new form
        $("[data-formset][data-formset-prefix='elections']").on('formAdded', function(e){
            var $new_form = $(e.target);
            var dates_names = ['proposition_begin_date', 'proposition_end_date',
            'roll_begin_date', 'roll_end_date', 'voting_begin_date', 'voting_end_date',
            'voting_references_date', 'minute_publication_date', 'minute_begin_date',
            'minute_end_date']

            var first_date = $new_form.find("[name$='proposition_begin_date']");

            if (!first_date.val()) {
                $.each(dates_names, function(index, elem){
                    var value = $(e.currentTarget).find("[name$='0-" + elem + "']").val();
                    $new_form.find("[name$='" + elem + "']").val(value);
                });
            }
        });
    });

})(jQuery);
