from evotevotings.management.tables import (ElectoralProcessDetailTable,
                                            ElectoralMemberTable)

from evotevotings.elections.tests.utils import ElectionsTestUtils

from . import ManagementTestCase


class ElectoralProcessDetailTableTest(ElectionsTestUtils, ManagementTestCase):
    """
    Test custom fields of electoral process detail table
    """

    def setUp(self):
        self.process = self.create_electoral_process()
        self.table = ElectoralProcessDetailTable({})

    def test_render_electoral_documents_empty(self):
        content = self.table.render_electoral_documents(self.process)
        self.assertEqual(content, 0)

    def test_render_elections_empty(self):
        content = self.table.render_elections(self.process)
        self.assertEqual(content, 0)

    def test_render_electoral_documents(self):
        self.create_electoral_document(electoral_process=self.process)
        self.create_electoral_document(electoral_process=self.process)
        content = self.table.render_electoral_documents(self.process)
        self.assertEqual(content, 2)

    def test_render_elections(self):
        self.create_election(electoral_process=self.process)
        content = self.table.render_elections(self.process)
        self.assertEqual(content, 1)


class ElectoralMemberTableTest(ElectionsTestUtils, ManagementTestCase):
    """
    Test custom fields of electoral member table
    """

    def setUp(self):
        self.process = self.create_electoral_process()
        self.table = ElectoralMemberTable({})

    def test_render_edit(self):
        member = self.create_electoral_member(electoral_process=self.process)
        expected = "<a href='#' data-partial-url='/en/1/members/1/edit/'>" +\
            "<i class='ev-icon evi-edit'></i></a>"
        content = self.table.render_edit(member)
        self.assertEqual(content, expected)


class ElectoralRollTableTest(ElectionsTestUtils, ManagementTestCase):
    """ """

    def setUp(self):
        self.electoral_roll = self.create_electoral_roll()

    def test_render_created(self):
        pass

    def test_render_actions_with_published_rolls(self):
        pass

    def test_render_actions_with_to_publish_rolls(self):
        pass
