from django.test import TestCase
from django.utils import timezone

from evotevotings.processes.models import ElectoralProcess

from evotevotings.processes.tests.utils import ProcessesTestUtils
from evoteusers.tests.utils import UserTestUtils


class ElectoralProcessManagerTest(ProcessesTestUtils, UserTestUtils, TestCase):
    """
    Test Managers of Electoral Process
    """

    def test_published(self):

        self.create_electoral_process(publication_date=timezone.now())
        self.create_electoral_process(publication_date=timezone.now())
        self.create_electoral_process(
            publication_date=timezone.now(), state=ElectoralProcess.State.OPEN)

        valid_qs = ElectoralProcess.objects.filter(
            publication_date__lte=timezone.now(),
            state=ElectoralProcess.State.OPEN)
        published = ElectoralProcess.objects.published()

        self.assertQuerysetEqual(valid_qs, map(repr, published))

    def test_belongs_to_institutional_member(self):
        user = self.create_user()
        self.create_electoral_process(created_by=user)
        self.create_electoral_process()
        valid_qs = ElectoralProcess.objects.filter(created_by=user)
        by_qs = ElectoralProcess.objects.belongs_to_institutional_member(user)
        self.assertQuerysetEqual(valid_qs, map(repr, by_qs))
