from rest_framework.response import Response
from rest_framework.generics import CreateAPIView
from rest_framework.renderers import JSONRenderer
from .utils import (generate_blind_signature,
                    unsign_election_id,
                    check_vote_status)
from . import serializers
from django.http import HttpResponseBadRequest


class ValidateVoteView(CreateAPIView):
    """
    Standard API view
    """
    permission_classes = []
    serializer_class = serializers.ValidateVoteSerializer

    def get_serializer_class(self):
        """
        Define the Serializer class to be interpreted
        by Django Swagger
        """
        return self.serializer_class

    def post(self, request, *args, **kwargs):
        """
        POST method docs
        Returns a JSON object with blind signature
        Return codes (0 < code < 10 for cripto errors):
            0 - No errors found
            1 - Empty data
            2 - Invalid data received
        """
        return_code = 0
        obj_data = {}
        return_data = {}
        serializer = serializers.ValidateVoteSerializer(data=request.data)
        if(serializer.is_valid(raise_exception=False)):
            blind_signature = generate_blind_signature(serializer.data)
            if(blind_signature is None):
                return_code = 2
            else:
                obj_data = blind_signature
        else:
            return_code = 1

        return_data['return_code'] = return_code
        return_data['data'] = obj_data
        return Response(JSONRenderer().render(return_data))


class ValidateSignatureView(CreateAPIView):
    """
    Standard API view
    """
    permission_classes = []
    serializer_class = serializers.ValidateSignatureSerializer

    def get_serializer_class(self):
        """
        Define the Serializer class to be interpreted
        by Django Swagger
        """
        return self.serializer_class

    def post(self, request, *args, **kwargs):
        """

        POST method docs
        Returns either true or false
        """
        serializer = serializers.ValidateSignatureSerializer(data=request.data)
        if(serializer.is_valid(raise_exception=False)):
            sanitized_data = serializer.validate(serializer.data)
            election_id = unsign_election_id(
                                sanitized_data['signed_election_id'])
            blind_hash = sanitized_data['blind_hash']
            return_data = check_vote_status(blind_hash, election_id)

            return Response(JSONRenderer().render(return_data))

        return HttpResponseBadRequest()
