from django import forms
from django.utils.translation import ugettext_lazy as _
from django.core.validators import RegexValidator

from evotecore import widgets
from evotevotings.elections.models import Candidate

from captcha.fields import ReCaptchaField


class PerPageFiltersForm(forms.Form):
    """ """

    PER_PAGE_CHOICES = [(5, 5), (10, 10)]

    per_page = forms.ChoiceField(choices=PER_PAGE_CHOICES,
                                 label=_(u'See by page'), required=False,
                                 widget=widgets.Select)

    class Meta:
        fields = ('per_page')


class IndexFiltersForm(forms.Form):
    """ """

    PER_PAGE_CHOICES = [(5, 5), (10, 10)]

    per_page = forms.ChoiceField(choices=PER_PAGE_CHOICES,
                                 label=_(u'See by page'), required=False,
                                 widget=widgets.Select)

    class Meta:
        fields = ('per_page')


class ElectionVotingStep1Form(forms.Form):
    """ """
    # Hidden session fields
    session_fields = ['combo_id', 'election_id', 'pr_components',
                      'election_cert', 'vs_cert', ]
    candidates_list_0 = forms.ModelMultipleChoiceField(
        required=True,
        queryset=Candidate.objects.none(),
        widget=forms.CheckboxSelectMultiple)

    # {User + Election ID}sv
    combo_id = forms.CharField(widget=forms.HiddenInput)
    # {Election ID}sv
    election_id = forms.CharField(widget=forms.HiddenInput)
    # prDashComponents
    pr_components = forms.CharField(widget=forms.HiddenInput)
    # Election Certificate
    election_cert = forms.CharField(widget=forms.HiddenInput)
    # Validator Service Certificate
    vs_cert = forms.CharField(widget=forms.HiddenInput)

    def __init__(self, *args, **kwargs):
        """" """
        election = kwargs.pop('instance')
        kw_combo_id = kwargs.pop('combo_id', None)
        kw_election_id = kwargs.pop('election_id', None)
        kw_vs_cert = kwargs.pop('vs_cert', None)
        super(ElectionVotingStep1Form, self).__init__(*args, **kwargs)

        # Election Model data
        self.initial['pr_components'] = election.blindsig_pr_dash_components
        self.initial['election_cert'] = election.certificate
        # Election extra data
        self.initial['combo_id'] = kw_combo_id
        self.initial['election_id'] = kw_election_id
        self.initial['vs_cert'] = kw_vs_cert

        if election.is_list_mode():
            self.fields['candidates_list_0'].queryset = \
                election.candidates.all()

        if not election.is_list_mode():
            choices = election.limit_remarkable_choices
            for n in range(0, choices):
                self.fields["candidates_list_%d" % n] = forms.ModelChoiceField(
                    empty_label=_('Select candidate'),
                    required=True,
                    queryset=election.candidates.all(),
                    widget=widgets.Select)

    def get_session_fields(self):
        """ """
        return [field for field in self
                if field.name in self.session_fields]

    def get_nonsession_fields(self):
        """ """
        return [field for field in self
                if field.name not in self.session_fields]


class ElectionSearchVoteForm(forms.Form):
    """ """

    search = forms.CharField(
        required=False, widget=forms.TextInput(attrs={
            'placeholder': _(u'Insert your voting reference here')}))

    class Meta:
        fields = ('search')


class ContactsForm(forms.Form):
    """ """
    textvalidator = RegexValidator(
        r'\d+', _('Only text characters are allowed.'), inverse_match=True)

    name = forms.CharField(
        label=_("Name"), max_length=254, validators=[textvalidator],
        widget=forms.TextInput(attrs={
            'autofocus': True,
            'placeholder': _("Name"),
            'autocomplete': 'off'
        }))
    email = forms.EmailField(
        label=_("Email"), max_length=254, widget=forms.EmailInput(attrs={
            'autofocus': True,
            'placeholder': _("Email"),
            'autocomplete': 'off'
        }))
    subject = forms.CharField(
        label=_("Subject"), max_length=254, widget=forms.TextInput(attrs={
            'autofocus': True,
            'placeholder': _("Subject"),
            'autocomplete': 'off'
        }))
    message = forms.CharField(
        label=_("Message"), widget=forms.Textarea(attrs={
            'autofocus': True,
            'placeholder': _("Message"),
            'autocomplete': 'off',
            'rows': 4
        }))
    captcha = ReCaptchaField()
